@@ -638,7 +638,7 @@ class ModelInterface(ABC):
     def distributed_chat(
         self,
         prompts: list[Thread],
-        post_logic: Optional[callable] = None,
+        post_logic: Callable | None = None,
         max_threads: int = 10,
         retry: int = 3,
         pbar=True,
@@ -652,7 +652,7 @@ class ModelInterface(ABC):
     async def distributed_chat_async(
         self,
         prompts: list[Thread],
-        post_logic: Optional[callable] = None,
+        post_logic: Callable | None = None,
         max_threads: int = 10,
         retry: int = 3,
         pbar=True,
